boto v2.10.0 — boto v2.15.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.15.0 »

# boto v2.10.0

date: | 2013/08/13

This release adds Mobile Push Notification support to Amazon Simple Notification Service, better reporting for Amazon Redshift, SigV4 authorization for Amazon Elastic MapReduce & lots of bugfixes.

## Features

- Added support for Mobile Push Notifications to SNS. This enables you to send push notifications to mobile devices (such as iOS or Android) using SNS. (commit ccba574)
- Added support for better reporting within Redshift. (commit 9d55dd3)
- Switched Elastic MapReduce to use SigV4 for authorization. (commit b80aa48)

## Bugfixes

- Added the `MinAdjustmentType` parameter to EC2 Autoscaling. (issue 1562, issue 1619, commit 1760284, commit 2a11fd9, commit 2d14006 & commit b7f1ae1)

- Fixed how DynamoDB tracks changes to data in `Item` objects, fixing failures with modified sets not being sent. (issue 1565, commit b111fcf & commit 812f9a6)

- Updated the CA certificates Boto ships with. (issue 1578, commit 4dfadc8)

- Fixed how CloudSearch’s `Layer2` object gets initialized. (issue 1629, issue 1630, commit 40b3652 & commit f797ff9)

- Fixed the `-w` flag in `s3put`. (issue 1637, commit 0865004 & commit 3fe70ca)

- Added the `ap-southeast-2` endpoint for DynamoDB. (issue 1621, commit 501b637)

- Fixed test suite to run faster. (commit 243a67e)

- Fixed how non-JSON responses are caught from CloudSearch. (issue 1633, issue 1645, commit d5a5c01, commit 954a50c, commit 915d8ff & commit 4407fcb)

- Fixed how `DeviceIndex` is parsed from EC2. (issue 1632, issue 1646, commit ff15e1f, commit 8337a0b & commit 27c9b04)

- Fixed EC2’s `connect_to_region` to respect the `region` parameter. ( issue 1616, issue 1654, commit 9c37256, commit 5950d12 & commit b7eebe8)

- Added `modify_network_interface_atribute` to EC2 connections. (issue 1613, issue 1656, commit e00b601, commit 5b62f27, commit 126f6e9, commit bbfed1f & commit 0c61293)

- Added support for `param_group` within RDS. (issue 1639, commit c47baf0)

- Added support for using `Item.partial_save` to create new records within DynamoDBv2. (issue 1660, issue 1521, commit bfa469f & commit 58a13d7)

- Several documentation improvements/fixes:

  > - Updated guideline on how core should merge PRs. (commit 80a419c)
  > - Fixed a typo in a CloudFront docstring. (issue 1657, commit 1aa0621)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.15.0 »